summaryrefslogtreecommitdiff
path: root/cups/http-support.c
diff options
context:
space:
mode:
authormsweet <msweet@a1ca3aef-8c08-0410-bb20-df032aa958be>2013-12-05 19:51:58 +0000
committermsweet <msweet@a1ca3aef-8c08-0410-bb20-df032aa958be>2013-12-05 19:51:58 +0000
commitf4047845ec1c8be7e335c904a424a0b00c9364cb (patch)
tree78dc7be2805bf4a466ced3198f10e041165edb4c /cups/http-support.c
parentdafebafde584d49edaa75282d5a30e7a1728b713 (diff)
downloadcups-f4047845ec1c8be7e335c904a424a0b00c9364cb.tar.gz
Fix builds.
Fix tel: URIs (<rdar://problem/15418463>) git-svn-id: svn+ssh://src.apple.com/svn/cups/cups.org/trunk@11444 a1ca3aef-8c08-0410-bb20-df032aa958be
Diffstat (limited to 'cups/http-support.c')
-rw-r--r--cups/http-support.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/cups/http-support.c b/cups/http-support.c
index bea6b7a79..bec268343 100644
--- a/cups/http-support.c
+++ b/cups/http-support.c
@@ -192,10 +192,10 @@ httpAssembleURI(
if (!ptr)
goto assemble_overflow;
- if (!strcmp(scheme, "mailto"))
+ if (!strcmp(scheme, "mailto") || !strcmp(scheme, "tel"))
{
/*
* mailto: only has :, no //...
*/
if (ptr < end)
@@ -206,7 +206,7 @@ httpAssembleURI(
else
{
/*
* Schemes other than mailto: all have //...
*/
if ((ptr + 2) < end)
@@ -1059,7 +1059,7 @@ httpSeparateURI(
*port = 515;
else if (!strcmp(scheme, "socket")) /* Not yet registered with IANA... */
*port = 9100;
- else if (strcmp(scheme, "file") && strcmp(scheme, "mailto"))
+ else if (strcmp(scheme, "file") && strcmp(scheme, "mailto") && strcmp(scheme, "tel"))
status = HTTP_URI_STATUS_UNKNOWN_SCHEME;
/*
@@ -192,10 +192,10 @@ httpAssembleURI(
{
/*
- * mailto: only has :, no //...
+ * mailto: and tel: only have :, no //...
*/
if (ptr < end)
@@ -206,7 +206,7 @@ httpAssembleURI(
{
/*
- * Schemes other than mailto: all have //...
+ * Schemes other than mailto: and tel: all have //...
*/
if ((ptr + 2) < end)